==> allomedia-uhlive-0.8.1.tgz: package/README.md <==
# uhlive-js

Allomedia's Uhlive JavaScript library.

## Environments in which to use the library

-   [x] Google Chrome (and Chrome-based browsers)
-   [x] Mozilla Firefox
-   [ ] Safari
-   [ ] Nodejs

## Requirements

Make sure you have Nodejs and NPM/Yarn installed to install this package.

## How to build

This package supports Node v12 LTS and higher. It's highly recommended to use the latest LTS version of node, and the documentation is written using syntax and features from that version.

Then make sure you have the necessary dependencies:

```bash
npm ci
```

Then, run the build script:

```bash
npm run build
```

The built version will be put in the `dist/` subdirectory, along with the associated map file and the type specifications.

## Lint

```bash
npm run lint
```

and to fix what is automatically fixable:

```bash
npm run lint:fix
```

## Running the tests

```bash
npm test
```

## Generate the documentation

```bash
npm run doc
```

## All of the above, with one command

```bash
npm run ci
```

This will, in this order:

-   lint the code
-   typecheck the code
-   test the code
-   build the app in `./dist`
-   generate the documentation

## Development

To display a page for debugging:

-   set your token and server URL in `examples/settings.js`.
-   run a web server with `npm start`.

This will create a server accessible at [http://127.0.0.1:8080/examples/](http://127.0.0.1:8080/examples/)

In another terminal, run `npm run watch` to auto-build as you work:

```bash
npm run watch
```

## Build a NPM package

Create a NPM package, eg `allomedia-uhlive-VERSION.tgz`:

```bash
npm pack
```

_This will execute `npm run ci` before actually creating an NPM package. Once the package is created (in example folder), you can install it in the example as a classic npm dependency._

This package can then be installed locally from another demo directory using:

```bash
cd ~/uhlive-demo
npm init
npm install --no-cache /path/to/allomedia-uhlive-VERSION.tgz
```

_Note: We decided to NOT publish the package yet, since we're still in an early phase of development._

## Running the examples

-   In the root directory of the project, run the following commands:

    -   `npm ci`
    -   `npm pack`

-   In the `./examples` directory:

    -   Copy `settings.js.dist` to `settings.js`
    -   Set your API token in `settings.js`

-   Back in the root directory:

    -   Start the example with : `npm start`
    -   Go to [http://127.0.0.1:8080/examples/](http://127.0.0.1:8080/examples/)

==> allomedia-uhlive-0.14.0.tgz: package/README.md <==
# uhlive-js

Allomedia's Uhlive JavaScript library.

## Environments in which to use the library

-   [x] Google Chrome (and Chrome-based browsers)
-   [x] Mozilla Firefox
-   [ ] Safari
-   [ ] Nodejs

## Requirements

Make sure you have Nodejs and NPM/Yarn installed to install this package.

## How to build

This package supports Node v12 LTS and higher. It's highly recommended to use the latest LTS version of node, and the documentation is written using syntax and features from that version.

Then make sure you have the necessary dependencies:

```bash
npm ci
```

Then, run the build script:

```bash
npm run build
```

The built version will be put in the `dist/` subdirectory, along with the associated map file and the type specifications.

## Lint

```bash
npm run lint
```

and to fix what is automatically fixable:

```bash
npm run lint:fix
```

## Running the tests

```bash
npm test
```

## Generate the documentation

Generate a html documentation:

```bash
npm run doc-html
```

Generate a mardown documentation:

```bash
npm run doc
```

## All of the above, with one command

```bash
npm run ci
```

This will, in this order:

-   lint the code
-   typecheck the code
-   test the code
-   build the app in `./dist`
-   generate the documentation

## Development

To display a page for debugging:

-   set your token and server URL in `./dev/settings.js`.
-   run a web server with `npm start`.

This will create a server accessible at [http://127.0.0.1:8080/dev/](http://127.0.0.1:8080/dev/)

In another terminal, run `npm run watch` to auto-build as you work:

```bash
npm run watch
```

## Build a NPM package

Create a NPM package, eg `allomedia-uhlive-VERSION.tgz`:

```bash
npm pack
```

_This will execute `npm run ci` before actually creating an NPM package. Once the package is created, you can install it as a classic npm dependency._

This package can then be installed locally from another directory using:

```bash
cd ~/uhlive-test
npm init
npm install --no-cache /path/to/allomedia-uhlive-VERSION.tgz
```

_Note: We decided to NOT publish the package yet, since we're still in an early phase of development._
